rmodule: use program.ld for linking

Bring rmodule linking into the common linking method.
The __rmodule_entry symbol was removed while using
a more common _start symbol. The rmodtool will honor
the entry point found within the ELF header. Add
ENV_RMODULE so that one can distinguish the environment
when generating linker scripts for rmodules. Lastly,
directly use program.ld for the rmodule.ld linker script.

BUG=chrome-os-partner:44827
BRANCH=None
TEST=Built rambi and analyzed the relocatable ramstage,
     sipi_vector, and smm rmodules.

Change-Id: Iaa499eb229d8171272add9ee6d27cff75e7534ac
Signed-off-by: Aaron Durbin <adubin@chromium.org>
Reviewed-on: http://review.coreboot.org/11517
Tested-by: build bot (Jenkins)
Reviewed-by: Patrick Georgi <pgeorgi@google.com>
diff --git a/src/include/rmodule.h b/src/include/rmodule.h
index 719c6a6..03cdf76 100644
--- a/src/include/rmodule.h
+++ b/src/include/rmodule.h
@@ -73,9 +73,9 @@
 };
 
 #if IS_ENABLED(CONFIG_RELOCATABLE_MODULES)
 /* Rmodules have an entry point of named __rmodule_entry. */
 #define RMODULE_ENTRY(entry_) \
-	void __rmodule_entry(void *) __attribute__((alias (STRINGIFY(entry_))))
+	void _start(void *) __attribute__((alias (STRINGIFY(entry_))))
 #else
 #define RMODULE_ENTRY(entry_)
 #endif
@@ -73,9 +73,9 @@
 
 #if IS_ENABLED(CONFIG_RELOCATABLE_MODULES)
-/* Rmodules have an entry point of named __rmodule_entry. */
+/* Rmodules have an entry point of named _start. */
 #define RMODULE_ENTRY(entry_) \